pub struct Actor<E, M, S, V, T, B>where
E: Spawner + CryptoRng + Clock + Metrics,
M: Manager<PublicKey = S::PublicKey, Directory = <V::ApplicationBlock as ReshareBlock>::Directory>,
S: Scheme<V::Commitment>,
V: Variant,
V::ApplicationBlock: ReshareBlock,
<V::ApplicationBlock as ReshareBlock>::Signer: Signer<PublicKey = S::PublicKey>,
T: Strategy,
B: Blocker<PublicKey = S::PublicKey>,{ /* private fields */ }Expand description
DKG probe actor.
Implementations
Sourceimpl<E, M, S, V, T, B> Actor<E, M, S, V, T, B>where
E: Spawner + CryptoRng + Clock + Metrics,
M: Manager<PublicKey = S::PublicKey, Directory = <V::ApplicationBlock as ReshareBlock>::Directory>,
S: Scheme<V::Commitment>,
V: Variant,
V::ApplicationBlock: ReshareBlock,
<V::ApplicationBlock as ReshareBlock>::Signer: Signer<PublicKey = S::PublicKey>,
T: Strategy,
B: Blocker<PublicKey = S::PublicKey>,
impl<E, M, S, V, T, B> Actor<E, M, S, V, T, B>where
E: Spawner + CryptoRng + Clock + Metrics,
M: Manager<PublicKey = S::PublicKey, Directory = <V::ApplicationBlock as ReshareBlock>::Directory>,
S: Scheme<V::Commitment>,
V: Variant,
V::ApplicationBlock: ReshareBlock,
<V::ApplicationBlock as ReshareBlock>::Signer: Signer<PublicKey = S::PublicKey>,
T: Strategy,
B: Blocker<PublicKey = S::PublicKey>,
Sourcepub fn new(config: Config<E, M, S, V, T, B>) -> (Self, Mailbox<S, V>)
pub fn new(config: Config<E, M, S, V, T, B>) -> (Self, Mailbox<S, V>)
Create a probe actor and mailbox.
Sourcepub fn start<BSE, BRE>(self, boundaries: (BSE, BRE)) -> Handle<()> ⓘ
pub fn start<BSE, BRE>(self, boundaries: (BSE, BRE)) -> Handle<()> ⓘ
Start the probe actor.
The boundary network is the probe request channel used to sample the configured committee’s latest finalizations, fetch the target epoch’s boundary finalization and block, and later serve the same requests to other joining peers.