pub struct Config<E, M, S, V, T, B>where
E: Spawner + CryptoRng + Clock + Metrics,
M: Manager<PublicKey = S::PublicKey, Directory = <V::ApplicationBlock as ReshareBlock>::Directory>,
S: Scheme<V::Commitment>,
V: Variant,
V::ApplicationBlock: ReshareBlock,
<V::ApplicationBlock as ReshareBlock>::Signer: Signer<PublicKey = S::PublicKey>,
T: Strategy,
B: Blocker<PublicKey = S::PublicKey>,{
pub context: E,
pub manager: M,
pub bootstrap: Bootstrap<S::PublicKey, <V::ApplicationBlock as ReshareBlock>::Directory>,
pub verifier: S,
pub genesis: EpochInfo<<V::ApplicationBlock as ReshareBlock>::Variant, S::PublicKey, <V::ApplicationBlock as ReshareBlock>::Directory>,
pub strategy: T,
pub blocker: B,
pub blocks_per_epoch: NonZeroU64,
pub retry_timeout: NonZeroDuration,
pub mailbox_size: NonZeroUsize,
pub block_codec_config: <V::ApplicationBlock as Read>::Cfg,
}Expand description
Configuration for the DKG probe actor.
Fields
context: ERuntime context.
manager: MP2P manager used to track the bootstrap participants when discovery begins.
bootstrap: Bootstrap<S::PublicKey, <V::ApplicationBlock as ReshareBlock>::Directory>The weakly subjective checkpoint to bootstrap from.
verifier: SAll-epoch certificate verifier built from the constant BLS identity.
genesis: EpochInfo<<V::ApplicationBlock as ReshareBlock>::Variant, S::PublicKey, <V::ApplicationBlock as ReshareBlock>::Directory>Public epoch information carried by genesis.
strategy: TStrategy for certificate verification.
blocker: BBlocker used to block peers that send invalid bootstrap data.
blocks_per_epoch: NonZeroU64Number of blocks in each epoch.
retry_timeout: NonZeroDurationHow long to wait before trying another boundary responder or re-broadcasting discovery.
mailbox_size: NonZeroUsizeMailbox capacity.
block_codec_config: <V::ApplicationBlock as Read>::CfgCodec configuration for application blocks received in boundary responses.