Message

Enum Message 

pub enum Message<B, V, C, A = Exact>
where B: ReshareBlock<Variant = V, Signer = C>, V: Variant, C: Signer, A: Acknowledgement,
{ NextLog { span: Span, height: Height, release: Sender<Self>, response: Sender<Option<LogReservation<B, V, C, A>>>, }, ReleaseLog { height: Height, }, EpochInfo { span: Span, ancestry: BoxedAncestry<B>, response: Sender<EpochInfoResponse<V, C, B::Directory>>, }, Finalized { span: Span, block: Arc<B>, response: A, }, }
A message that can be sent to the Actor.

Variants



NextLog

A request for the next finalized dealer log to include before the final block of the epoch.

height is the height of the block being proposed. The actor uses it to avoid re-offering a log into competing proposals while one it already served into may still finalize.

Fields

span: Span
height: Height
release: Sender<Self>
response: Sender<Option<LogReservation<B, V, C, A>>>


ReleaseLog

A proposal attempt was canceled or returned no block after receiving a dealer log.

Fields

height: Height


EpochInfo

A request for the final block’s speculative EpochInfo.

Fields

span: Span
ancestry: BoxedAncestry<B>
response: Sender<EpochInfoResponse<V, C, B::Directory>>


Finalized

A new block has been finalized.

Fields

span: Span
block: Arc<B>
response: A