pub struct TipUpdate<D: Digest, T> { /* private fields */ }Expand description
Tip update delivered to a live state-sync session.
The optional observation barrier is used by the stateful actor to delay marshal acknowledgement until the sync coordinator has recorded the new anchor and targets.
Implementations