Mailbox

Struct Mailbox 

pub struct Mailbox<E, A>
where E: Rng + Spawner + Metrics + Clock, A: Application<E>,
{ /* private fields */ }
Channel-based proxy to the Stateful actor.

Implements the consensus application and verifying traits by forwarding each call to the actor via a message and awaiting the response.

Implementations

Source

impl<E, A> Mailbox<E, A>
where E: Rng + Spawner + Metrics + Clock, A: Application<E>,

pub async fn subscribe_databases(&self) -> A::Databases

Wait for the attached database set.

This resolves once startup handoff has attached the database set to the serving actor. Late callers receive the current database set immediately.