PruneConfig

Struct PruneConfig 

pub struct PruneConfig {
    pub maintenance_interval: NonZeroUsize,
    pub retained_marshal_blocks: usize,
    pub retained_qmdb_blocks: usize,
}
Periodic pruning configuration.

Fields

maintenance_interval: NonZeroUsize

Finalized blocks between database and marshal pruning attempts.

Stateful selects a random phase within the interval when it starts. This controls only how often pruning runs, not how much history is retained.

retained_marshal_blocks: usize

Finalized blocks to retain in marshal beyond its acknowledgement window plus one.

This should generally be set to a large enough number of blocks to facilitate downtime on a validator that has completed state sync. If marshal retains too few blocks, a rebooted node may fail to recover due to peers being unable to serve the blocks it needs to catch up.

retained_qmdb_blocks: usize

Finalized blocks’ worth of operations to retain in QMDB beyond marshal’s acknowledgement window plus one.

This value is generally safe to set to 0, as QMDB operations below the active range are only needed to serve state sync requests for lagging peers. Some network topologies may benefit from a non-zero value here to provide a larger buffer for serving state sync requests during periods of instability.

Implementations

Source

impl PruneConfig

pub const fn assert_valid(self)

Ensure marshal is never pruned more aggressively than QMDB.