pub enum Payload<V: Variant, C: Signer, D: Directory<C::PublicKey> = Unit> {
DealerLog(SignedDealerLog<V, C>),
EpochInfo(EpochInfo<V, C::PublicKey, D>),
}Expand description
A public artifact published by the reshare actor into a block.
During the dealing and inclusion window of an epoch the actor publishes
finalized dealer logs. The final block of an epoch instead carries the
canonical EpochInfo for the following epoch.
Variants
DealerLog(SignedDealerLog<V, C>)
A finalized signed dealer log for inclusion mid-epoch.
EpochInfo(EpochInfo<V, C::PublicKey, D>)
The canonical public epoch artifact for the next epoch, carried by the final block of the current epoch.