pub trait AttachableResolver<DB>:
Clone
+ Send
+ Sync
+ 'static {
// Required method
fn attach_database(
&self,
db: Arc<AsyncRwLock<DB>>,
) -> impl Future<Output = ()> + Send;
}Expand description
A resolver that can attach a database at runtime.
Implementations receive a database handle after startup so they can serve incoming sync requests once the database is initialized.
Required Methods
Sourcefn attach_database(
&self,
db: Arc<AsyncRwLock<DB>>,
) -> impl Future<Output = ()> + Send
fn attach_database( &self, db: Arc<AsyncRwLock<DB>>, ) -> impl Future<Output = ()> + Send
Attach a database for serving incoming requests.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".