pub struct Mailbox<E, A>{ /* private fields */ }Expand description
Channel-based proxy to the Stateful actor.
Implements the consensus application and verifying traits by forwarding each call to the actor via a message and awaiting the response.
Implementations